@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2015 Maxime DOYEN
+ *	Copyright (C) 1995-2016 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -27,7 +27,6 @@
 
 #include "ui-account.h"
 #include "dsp_mainwindow.h"
-#include "hb-import-qif.h"
 
 
 
@@ -1230,11 +1229,6 @@ struct import_data *data;
 }
 
 
-
-
-
-
-
 static void _import_tryload_file(struct import_data *data)
 {
 ImportContext *ictx = &data->ictx;
@@ -1279,6 +1273,8 @@ ImportContext *ictx = &data->ictx;
 	_import_tryload_file(data);
 
 	// if fail, try to load with different date format
+
+
 	if( ictx->cnt_err_date > 0)
 	{
 	const gchar *encoding = ictx->encoding;
@@ -1286,21 +1282,35 @@ ImportContext *ictx = &data->ictx;
 
 		for(i=0;i<NUM_PRF_DATEFMT;i++)
 		{
+		gboolean do_fix;
+
 			if(i != PREFS->dtex_datefmt)	//don't reload with user pref date format
 			{
-				DB( g_print(" fail, reload with '%s'\n", CYA_IMPORT_DATEORDER[i]) );
-				//#1448549
-				import_clearall(data);
-				ictx->encoding = encoding; //#1425986 keep encoding with us
-				ictx->datefmt = i;
-				_import_tryload_file(data);
+				do_fix = ui_dialog_msg_question(
+					GTK_WINDOW(data->assistant),
+					_("Some date convertion failed"),
+					_("Reload using date order: '%s' ?"),
+					CYA_IMPORT_DATEORDER[i]
+					);
 
-				DB( g_print(" -> reloaded: nbtrans=%d, date errors=%d\n", ictx->cnt_new_ope, ictx->cnt_err_date) );
+				if(do_fix == GTK_RESPONSE_YES)
+				{	
+					DB( g_print(" fail, reload with '%s'\n", CYA_IMPORT_DATEORDER[i]) );
+					//#1448549
+					import_clearall(data);
+					ictx->encoding = encoding; //#1425986 keep encoding with us
+					ictx->datefmt = i;
+					_import_tryload_file(data);
+
+					DB( g_print(" -> reloaded: nbtrans=%d, date errors=%d\n", ictx->cnt_new_ope, ictx->cnt_err_date) );
+
+					if(ictx->cnt_err_date == 0)
+						break;
+				}
 
-				if(ictx->cnt_err_date == 0)
-					break;
 			}
 		}
+		
 	}
 
 	DB( g_print(" end of try import\n") );
@@ -1923,7 +1933,6 @@ gint crow, row;
 	gtk_container_add (GTK_CONTAINER (scrollwin), widget);
 	gtk_grid_attach (GTK_GRID (group_grid), scrollwin, 0, row, 2, 1);
 
-	row++;
 	expander = gtk_expander_new (_("Detail of existing transaction (possible duplicate)"));
 	data->GR_duplicate = expander;
 	gtk_grid_attach (GTK_GRID (group_grid), expander, 0, crow++, 2, 1);
@@ -2080,8 +2089,7 @@ GtkWidget *ui_import_assistant_new (gint filetype)
 {
 struct import_data *data;
 GtkWidget *assistant;
-GdkScreen *screen;
-gint width, height;
+gint w, h;
 gint pos;
 
 	data = g_malloc0(sizeof(struct import_data));
@@ -2100,27 +2108,10 @@ gint pos;
 	gtk_window_set_modal(GTK_WINDOW (assistant), TRUE);
 	gtk_window_set_transient_for(GTK_WINDOW(assistant), GTK_WINDOW(GLOBALS->mainwindow));
 
-#if FORCE_SIZE == 1
-	screen = gtk_window_get_screen(GTK_WINDOW (assistant));
-	// fix #379372 : manage multiple monitor case
-	if( gdk_screen_get_n_monitors(screen) > 1 )
-	{
-	GdkRectangle rect;
+	//set a nice dialog size
+	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
+	gtk_window_set_default_size (GTK_WINDOW(assistant), w*0.8, h*0.8);
 
-		gdk_screen_get_monitor_geometry(screen, 1, &rect);
-		width = rect.width;
-		height = rect.height;
-	}
-	else
-	{
-		width  = gdk_screen_get_width(screen);
-		height = gdk_screen_get_height(screen);
-	}
-
-	//gtk_window_resize(GTK_WINDOW(assistant), (height - 128) * PHI, height - 128);
-	gtk_window_resize(GTK_WINDOW(assistant), width/PHI, height/PHI);
-	gtk_window_set_position (GTK_WINDOW (assistant), GTK_WIN_POS_CENTER);
-#endif
 
 
 	pos = 0;
